@@ -3,9 +3,15 @@ Account
 =======
 """
 
-import deepcrawl
-from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
+from __future__ import annotations
 
+from typing import Optional, List, Union
+
+import requests
+
+import deepcrawl
+from deepcrawl.projects.projects import DeepCrawlProject
+from deepcrawl.utils import ImmutableAttributesMixin, safe_string_to_datetime
 
 account_extra_fields = (
     "id",
@@ -86,7 +92,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
                    'custom_domain', 'address_state', 'custom_support_email', 'custom_support_phone', 'timezone',
                    'finance_vat', 'splunk_enabled', 'active']
 
-    def __init__(self, account_data):
+    def __init__(self, account_data: dict):
         self.id = account_data.get("id")
         self.projects = []
 
@@ -148,14 +154,14 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
 
         super(DeepCrawlAccount, self).__init__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"[{self.id}] {self.name}"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.id}] {self.name}"
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -163,14 +169,16 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in account_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
         """
         return {x: getattr(self, x, None) for x in account_immutable_fields}
 
-    def load_projects(self, connection=None, filters=None, **kwargs):
+    def load_projects(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlProject]:
         """Loads projects into current instance
 
         >>> self.load_projects()
@@ -189,14 +197,14 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         :return:
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        self.projects = connection.get_projects(self.id, filters=filters, **kwargs)
+        self.projects: List[DeepCrawlProject] = connection.get_projects(self.id, filters=filters, **kwargs)
         return self.projects
 
     """
     ACCOUNT
     """
 
-    def save(self, connection=None):
+    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
         """Save account instance
 
         * if the instance id is None then the account will be created
@@ -216,7 +224,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         else:
             return connection.update_account(self.id, {key: getattr(self, key) for key in self.post_fields})
 
-    def refresh(self, connection=None):
+    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
         """Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
@@ -228,12 +236,12 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         :rtype: DeepCrawlAccount
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
-        account = connection.get_account(self.id)
+        account: DeepCrawlAccount = connection.get_account(self.id)
         for key in account_mutable_fields:
             setattr(self, key, getattr(account, key))
         return self
 
-    def update(self, account_settings, connection=None):
+    def update(self, account_settings, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlAccount:
         """Updates an instance with account_settings
 
         >>> self.update(account_settings)
@@ -256,7 +264,10 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
     """
     PROJECTS
     """
-    def create_project(self, project_settings, connection=None):
+
+    def create_project(
+            self, project_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProject:
         """Create project.
         Project settings argument can be dict or a ProjectSettings instance.
 
@@ -273,14 +284,16 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.create_project(self.id, project_settings)
 
-    def get_project(self, project_id, connection=None):
+    def get_project(
+            self, project_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProject:
         """Get Project
 
         >>> self.get_project(1)
         [0 1] www.test.com Project
 
         :param project_id: project id
-        :type project_id: int
+        :type project_id: int or str
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: Requested project
@@ -289,7 +302,10 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_project(self.id, project_id)
 
-    def update_project_settings(self, project_id, settings, connection=None):
+    def update_project_settings(
+            self, project_id: Union[int, str], settings: dict,
+            connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProject:
         """Update the project settings.
         Settings argument can be dict or a ProjectSettings instance.
 
@@ -297,7 +313,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         [0 1] www.test.com Project
 
         :param project_id: project id
-        :type project_id: int
+        :type project_id: int or str
         :param settings: new settings configuration
         :type settings: dict or ProjectSettings
         :param connection: connection
@@ -308,7 +324,9 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.update_project_settings(self.id, project_id, settings)
 
-    def delete_project(self, project_id, connection=None):
+    def delete_project(
+            self, project_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> requests.Response:
         """Delete project
 
         >>> response = self.delete_project(1)
@@ -316,7 +334,7 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         204
 
         :param project_id: project id
-        :type project_id: int
+        :type project_id: int or str
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
@@ -324,7 +342,10 @@ class DeepCrawlAccount(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.delete_project(self.id, project_id)
 
-    def get_projects(self, use_cache=True, connection=None, filters=None):
+    def get_projects(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None
+    ) -> List[DeepCrawlProject]:
         """Get projects
 
         * use_cache=True > get_projects will return cached projects or will do a call to DeepCrawl if projects attribute is empty.
