@@ -1,8 +1,10 @@
+from typing import Optional
+
 from deepcrawl.exceptions import InvalidContentType
 
 
 # Generate request headers with the API connection token and the appropriate content-type
-def get_request_headers(token="", content_type='json'):
+def get_request_headers(token: str = "", content_type: Optional[str] = 'json') -> dict:
     headers = {
         'X-Auth-Token': token,
         'Accept': '*/*',
