@@ -2,8 +2,15 @@
 Crawl
 =====
 """
+from __future__ import annotations
+
+from typing import Union, Optional, List
+
+from requests import Response
 
 import deepcrawl
+from deepcrawl.downloads.download import DeepCrawlCrawlDownloads
+from deepcrawl.reports.report import DeepCrawlReport
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
@@ -71,7 +78,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
 
     mutable_attributes = crawl_mutable_fields
 
-    def __init__(self, crawl_data, account_id, project_id):
+    def __init__(self, crawl_data: dict, account_id: Union[int, str], project_id: Union[int, str]):
         # relations
         self.id = crawl_data.get('id')
         self.account_id = account_id
@@ -123,14 +130,14 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
 
         super(DeepCrawlCrawl, self).__init__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"[{self.account_id} {self.project_id} {self.id}] {self.crawling_at}"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.account_id} {self.project_id} {self.id}] {self.crawling_at}"
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -138,14 +145,16 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in crawl_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
         """
         return {x: getattr(self, x, None) for x in crawl_immutable_fields}
 
-    def load_reports(self, connection=None, filters=None, **kwargs):
+    def load_reports(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReport]:
         """Loads reports into current instance
 
         >>> self.load_reports()
@@ -168,7 +177,9 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         self.reports = connection.get_reports(self.account_id, self.project_id, self.id, filters=filters, **kwargs)
         return self.reports
 
-    def load_reports_changes(self, connection=None, filters=None, **kwargs):
+    def load_reports_changes(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReport]:
         """Loads reports changes into current instance
 
         >>> self.load_reports_changes()
@@ -194,7 +205,9 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         )
         return self.reports
 
-    def load_downloads(self, connection=None, filters=None, **kwargs):
+    def load_downloads(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlDownloads]:
         """Loads reports downloads into current instance
 
         >>> self.load_downloads()
@@ -224,7 +237,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     CRAWL
     """
 
-    def refresh(self, connection=None):
+    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
         """Refresh crawl instance
 
         >>> self.refresh()
@@ -241,7 +254,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             setattr(self, key, getattr(crawl, key))
         return self
 
-    def update(self, crawl_data, connection=None):
+    def update(self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
         """Update crawl instance
 
         >>> self.update(crawl_data)
@@ -260,7 +273,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             setattr(self, key, getattr(crawl, key))
         return self
 
-    def delete(self, connection=None):
+    def delete(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
         """Delete current crawl instance
 
         >>> response = self.delete()
@@ -280,7 +293,9 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     REPORTS
     """
 
-    def get_report(self, report_id, connection=None):
+    def get_report(
+            self, report_id: str, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlReport:
         """Get report
 
         >>> self.get_report("4:duplicate_body_content:basic")
@@ -296,7 +311,10 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_report(self.account_id, self.project_id, self.id, report_id)
 
-    def get_reports(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_reports(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReport]:
         """Get reports for current instance
 
         * use_cache=True > get_reports will return cached reports or will do a call to DeepCrawl if reports attribute is empty.
@@ -322,7 +340,10 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
             return self.reports
         return self.load_reports(connection=connection, filters=filters, **kwargs)
 
-    def get_reports_changes(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_reports_changes(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReport]:
         """Get reports changes for current instance
 
         * use_cache=True > get_reports_changes will return cached reports changes or will do a call to DeepCrawl if reports_changes attribute is empty.
@@ -352,7 +373,10 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
     DOWNLOADS
     """
 
-    def get_downloads(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_downloads(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawlDownloads]:
         """Get reports downloads for current instance
 
         * use_cache=True > get_downloads will return cached reports downloads or will do a call to DeepCrawl if downloads attribute is empty.
@@ -370,7 +394,7 @@ class DeepCrawlCrawl(ImmutableAttributesMixin):
         :type kwargs: dict
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
-        :return: list of issues
+        :return: list of downloads
         :rtype: list
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
