@@ -3,6 +3,8 @@ Download
 ========
 """
 
+from typing import Union
+
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
@@ -47,7 +49,10 @@ class DeepCrawlCrawlDownloads(ImmutableAttributesMixin):
 
     mutable_attributes = crawl_download_mutable_fields
 
-    def __init__(self, download_data, account_id, project_id, crawl_id):
+    def __init__(
+            self, download_data: dict,
+            account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str]
+    ):
         # relations
         self.account_id = account_id
         self.project_id = project_id
@@ -77,14 +82,14 @@ class DeepCrawlCrawlDownloads(ImmutableAttributesMixin):
 
         super(DeepCrawlCrawlDownloads, self).__init__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"[{self.id}] {self.report_name.title()} {self.report_type} - {self.output_type} ({self.status})"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.id}] {self.report_name.title()} {self.report_type} - {self.output_type} ({self.status})"
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -92,7 +97,7 @@ class DeepCrawlCrawlDownloads(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in crawl_download_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
@@ -135,7 +140,10 @@ class DeepCrawlReportDownload(ImmutableAttributesMixin):
 
     mutable_attributes = report_download_mutable_fields
 
-    def __init__(self, account_id, project_id, crawl_id, report_id, download_data: dict):
+    def __init__(
+            self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
+            report_id: str, download_data: dict
+    ):
         # relations
         self.id = download_data.get("id")
         self.account_id = account_id
@@ -158,7 +166,7 @@ class DeepCrawlReportDownload(ImmutableAttributesMixin):
         super(DeepCrawlReportDownload, self).__init__()
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -166,7 +174,7 @@ class DeepCrawlReportDownload(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in report_download_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
