@@ -2,8 +2,18 @@
 Project
 =======
 """
+from __future__ import annotations
+
+from typing import Union, Optional, List
+
+from requests import Response
 
 import deepcrawl
+from deepcrawl.crawls.crawl import DeepCrawlCrawl
+from deepcrawl.projects.issues import DeepCrawlIssue
+from deepcrawl.projects.majestic_settings import MajesticSettings
+from deepcrawl.projects.project_upload import DeepCrawlProjectUpload
+from deepcrawl.projects.schedule import DeepCrawlSchedule
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 from .extractions import DeepCrawlExtraction
@@ -44,7 +54,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
     mutable_attributes = project_mutable_fields
 
-    def __init__(self, project_data, account_id):
+    def __init__(self, project_data: dict, account_id: Union[int, str]):
         # relations
         self.id = project_data.get('id')
         self.account_id = account_id
@@ -76,14 +86,14 @@ class DeepCrawlProject(ImmutableAttributesMixin):
 
         super(DeepCrawlProject, self).__init__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"[{self.account_id} {self.id}] {self.project_settings.name}"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.account_id} {self.id}] {self.project_settings.name}"
 
     @property
-    def to_dict(self):
+    def to_dict(self) -> dict:
         """
         :return: dictionary with the project fields
         :rtype: dict
@@ -102,7 +112,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return dict_
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -110,14 +120,16 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in project_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
         """
         return {x: getattr(self, x, None) for x in project_immutable_fields}
 
-    def load_project_uploads(self, connection=None, filters=None, **kwargs):
+    def load_project_uploads(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlProjectUpload]:
         """Loads crawls into current instance
 
         >>> self.load_project_uploads()
@@ -138,7 +150,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.project_uploads = connection.get_project_uploads(self.account_id, self.id, filters=filters, **kwargs)
         return self.project_uploads
 
-    def load_crawls(self, connection=None, filters=None, **kwargs):
+    def load_crawls(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawl]:
         """Loads crawls into current instance
 
         >>> self.load_crawls()
@@ -161,7 +175,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.crawls = connection.get_crawls(self.account_id, self.id, filters=filters, **kwargs)
         return self.crawls
 
-    def load_issues(self, connection=None, filters=None, **kwargs):
+    def load_issues(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlIssue]:
         """Loads issues into current instance
 
         >>> self.load_issues()
@@ -183,7 +199,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.issues = connection.get_issues(self.account_id, self.id, filters=filters, **kwargs)
         return self.issues
 
-    def load_schedules(self, connection=None, filters=None, **kwargs):
+    def load_schedules(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlSchedule]:
         """Loads schedules into current instance
 
         >>> self.load_schedules()
@@ -210,7 +228,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     PROJECT
     """
 
-    def save(self, connection=None):
+    def save(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlProject:
         """Save project instance
 
         * if the instance id is None then the project will be created
@@ -230,7 +248,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         else:
             return connection.update_project_settings(self.account_id, self.id, self.project_settings.to_dict)
 
-    def refresh(self, connection=None):
+    def refresh(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlProject:
         """Makes a call to DeepCrawl in order to refresh the current instance.
 
         >>> self.refresh()
@@ -247,7 +265,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
             setattr(self, key, getattr(project, key))
         return self
 
-    def update_settings(self, project_settings, connection=None):
+    def update_settings(
+            self, project_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProject:
         """Updates current project instance with another project_settings.
         Settings argument can be dict or a ProjectSettings instance.
 
@@ -267,7 +287,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.project_settings = project.project_settings
         return self
 
-    def delete(self, connection=None):
+    def delete(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
         """Delete current project instance
 
         >>> response = self.delete()
@@ -282,7 +302,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         response = connection.delete_project(self.account_id, self.id)
         return response
 
-    def add_extractions(self, extractions, connection=None):
+    def add_extractions(
+            self, extractions: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProject:
         """Add extractions to current project
 
         .. code-block::
@@ -325,7 +347,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     PROJECT UPLOAD
     """
 
-    def create_project_upload(self, upload_data: dict, files, connection=None):
+    def create_project_upload(
+            self, upload_data: dict, files: list, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProjectUpload:
         """Create project upload
 
         >>> self.create_project_upload(upload_data, files)
@@ -344,7 +368,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         project_upload = connection.create_project_upload(self.account_id, self.id, upload_data, files)
         return project_upload
 
-    def get_project_upload(self, project_upload_id, connection=None):
+    def get_project_upload(
+            self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProjectUpload:
         """Get project upload
 
         >>> self.get_project_upload(5)
@@ -361,7 +387,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         project_upload = connection.get_project_upload(self.account_id, self.id, project_upload_id)
         return project_upload
 
-    def enable_project_upload(self, project_upload_id, connection=None):
+    def enable_project_upload(
+            self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProjectUpload:
         """Enable project upload
 
         >>> self.enable_project_upload(5)
@@ -378,7 +406,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         project_upload = connection.enable_project_upload(self.account_id, self.id, project_upload_id)
         return project_upload
 
-    def disable_project_upload(self, project_upload_id, connection=None):
+    def disable_project_upload(
+            self, project_upload_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlProjectUpload:
         """Disable project upload
 
         >>> self.disable_project_upload(5)
@@ -395,13 +425,17 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         project_upload = connection.disable_project_upload(self.account_id, self.id, project_upload_id)
         return project_upload
 
-    def delete_project_upload(self, project_upload_id, connection=None):
+    def delete_project_upload(
+            self, project_upload_id, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> Response:
         """Delete current issue instance
 
         >>> response = self.delete_project_upload(5)
         >>> response.status_code
         204
 
+        :param project_upload_id: project upload id
+        :type project_upload_id: int
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
@@ -410,10 +444,14 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         response = connection.delete_project_upload(self.account_id, self.id, project_upload_id)
         return response
 
-    def get_project_uploads(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_project_uploads(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlProjectUpload]:
         """Get project uploads for current instance
 
-        * use_cache=True > get_project_uploads will return cached project uploads or will do a call to DeepCrawl if project_uploads attribute is empty.
+        * use_cache=True > get_project_uploads will return cached project uploads or will do a call to DeepCrawl
+            if project_uploads attribute is empty.
         * use_cache=False > get_project_uploads will call DeepCrawl api and will override project_uploads attribute.
 
         >>> self.get_project_uploads()
@@ -439,7 +477,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     MAJESTIC
     """
 
-    def get_majestic_settings(self, connection=None):
+    def get_majestic_settings(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> MajesticSettings:
         """Update majestic settings
 
         >>> self.get_majestic_settings()
@@ -455,7 +493,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         self.majestic_settings = connection.get_majestic_settings(self.account_id, self.id)
         return self.majestic_settings
 
-    def refresh_majestic_settings(self, connection=None):
+    def refresh_majestic_settings(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> MajesticSettings:
         """Refresh majestic settings
 
         >>> self.refresh_majestic_settings()
@@ -465,13 +503,15 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: refreshed majestic settings
-        :rtype: list
+        :rtype: MajesticSettings
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         self.majestic_settings = self.get_majestic_settings(connection=connection)
         return self.majestic_settings
 
-    def update_majestic_settings(self, majestic_settings, connection=None):
+    def update_majestic_settings(
+            self, majestic_settings: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> MajesticSettings:
         """Update majestic settings.
         Majestic settings argument can be dict or a MajesticSettings instance.
 
@@ -494,7 +534,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     ISSUES
     """
 
-    def create_issue(self, issue_data, connection=None):
+    def create_issue(self, issue_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlIssue:
         """Create issue
 
         >>> self.create_issue(issue_data)
@@ -511,7 +551,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         issue = connection.create_issue(self.account_id, self.id, issue_data)
         return issue
 
-    def get_issue(self, issue_id, connection=None):
+    def get_issue(
+            self, issue_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlIssue:
         """Get issue
 
         >>> self.get_issue(3)
@@ -528,7 +570,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         issue = connection.get_issue(self.account_id, self.id, issue_id)
         return issue
 
-    def update_issue(self, issue_id, issue_data, connection=None):
+    def update_issue(
+            self, issue_id: Union[int, str], issue_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlIssue:
         """Update issue
 
         >>> self.update_issue(3, issue_data)
@@ -540,19 +584,24 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         :type issue_data: dict
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
-        :return:
+        :return: issue instance
+        :rtype: DeepCrawlIssue
         """
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         issue = connection.update_issue(self.account_id, self.id, issue_id, issue_data)
         return issue
 
-    def delete_issue(self, issue_id, connection=None):
+    def delete_issue(
+            self, issue_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> Response:
         """Delete current issue instance
 
         >>> response = self.delete_issue(3)
         >>> response.status_code
         204
 
+        :param issue_id: issue id
+        :type issue_id: int
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
@@ -561,7 +610,10 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         response = connection.delete_issue(self.account_id, self.id, issue_id)
         return response
 
-    def get_issues(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_issues(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlIssue]:
         """Get issues for current instance
 
         * use_cache=True > get_issues will return cached issues or will do a call to DeepCrawl if issues attribute is empty.
@@ -590,7 +642,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     CRAWLS
     """
 
-    def start_crawl(self, connection=None):
+    def start_crawl(self, connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
         """Start a new crawl
 
         >>> response = self.start_crawl()
@@ -604,7 +656,7 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.start_crawl(self.account_id, self.id)
 
-    def create_crawl(self, crawl_data, connection=None):
+    def create_crawl(self, crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None) -> DeepCrawlCrawl:
         """Create crawl
 
         >>> self.create_crawl(crawl_data)
@@ -620,14 +672,16 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.create_crawl(self.account_id, self.id, crawl_data)
 
-    def get_crawl(self, crawl_id, connection=None):
+    def get_crawl(
+            self, crawl_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlCrawl:
         """Get crawl
 
         >>> self.get_crawl(3)
         [0 1 3] 2020-03-22 12:09:11+00:00
 
         :param crawl_id: crawl id
-        :type crawl_id: int
+        :type crawl_id: int or str
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: crawl instance
@@ -636,14 +690,16 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_crawl(self.account_id, self.id, crawl_id)
 
-    def update_crawl(self, crawl_id, crawl_data, connection=None):
+    def update_crawl(
+            self, crawl_id: Union[int, str], crawl_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlCrawl:
         """Update crawl
 
         >>> self.update_crawl(3, crawl_data)
         [0 1 3] 2020-04-23 11:10:11+00:00
 
         :param crawl_id: crawl id
-        :type crawl_id: int
+        :type crawl_id: int or str
         :param crawl_data: crawl configuration
         :type crawl_data: dict
         :param connection: connection
@@ -655,13 +711,15 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         crawl = connection.update_crawl(self.account_id, self.id, crawl_id, crawl_data)
         return crawl
 
-    def delete_crawl(self, crawl_id, connection=None):
+    def delete_crawl(self, crawl_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None) -> Response:
         """Delete current crawl instance
 
         >>> response = self.delete_crawl(3)
         >>> response.status_code
         204
 
+        :param crawl_id: crawl id
+        :type crawl_id: int or str
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
@@ -669,7 +727,10 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.delete_crawl(self.account_id, self.id, crawl_id)
 
-    def get_crawls(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_crawls(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlCrawl]:
         """Get issues for current instance
 
         * use_cache=True > get_crawls will return cached crawls or will do a call to DeepCrawl if crawls attribute is empty.
@@ -698,7 +759,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
     SCHEDULES
     """
 
-    def create_schedule(self, schedule_data, connection=None):
+    def create_schedule(
+            self, schedule_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlSchedule:
         """Create schedule
 
         >>> self.create_schedule(schedule_data)
@@ -714,7 +777,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.create_schedule(self.account_id, self.id, schedule_data)
 
-    def get_schedule(self, schedule_id, connection=None):
+    def get_schedule(
+            self, schedule_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlSchedule:
         """Get schedule
 
         >>> self.get_schedule(3)
@@ -730,7 +795,9 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_schedule(self.account_id, self.id, schedule_id)
 
-    def update_schedule(self, schedule_id, schedule_data, connection=None):
+    def update_schedule(
+            self, schedule_id: Union[int, str], schedule_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlSchedule:
         """Update schedule
 
         >>> self.update_schedule(3, schedule_data)
@@ -749,13 +816,17 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         schedule = connection.update_schedule(self.account_id, self.id, schedule_id, schedule_data)
         return schedule
 
-    def delete_schedule(self, schedule_id, connection=None):
+    def delete_schedule(
+            self, schedule_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> Response:
         """Delete current schedule instance
 
         >>> response = self.delete_schedule(3)
         >>> response.status_code
         204
 
+        :param schedule_id: issue id
+        :type schedule_id: int
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: HTTP 204 No Content
@@ -763,7 +834,10 @@ class DeepCrawlProject(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.delete_schedule(self.account_id, self.id, schedule_id)
 
-    def get_schedules(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_schedules(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlSchedule]:
         """Get schedules for current instance
 
         * use_cache=True > get_schedules will return cached schedules or will do a call to DeepCrawl if schedules attribute is empty.
