@@ -2,8 +2,13 @@
 Report
 ======
 """
+from typing import Union, Optional, List
+
+from requests import Response
 
 import deepcrawl
+from deepcrawl.downloads.download import DeepCrawlReportDownload
+from deepcrawl.reports.report_row import DeepCrawlReportRow
 from deepcrawl.utils import ImmutableAttributesMixin
 
 report_extra_fields = (
@@ -61,7 +66,9 @@ class DeepCrawlReport(ImmutableAttributesMixin):
 
     mutable_attributes = report_mutable_fields
 
-    def __init__(self, account_id, project_id, crawl_id, report_data: dict):
+    def __init__(
+            self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str], report_data: dict
+    ):
         # relations
         self.id = report_data.get("id")
         self.account_id = account_id
@@ -104,14 +111,14 @@ class DeepCrawlReport(ImmutableAttributesMixin):
 
         super(DeepCrawlReport, self).__init__()
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"[{self.account_id} {self.project_id} {self.crawl_id}] {self.id}"
 
-    def __str__(self):
+    def __str__(self) -> str:
         return f"[{self.account_id} {self.project_id} {self.crawl_id}] {self.id}"
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -119,14 +126,16 @@ class DeepCrawlReport(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in report_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
         """
         return {x: getattr(self, x, None) for x in report_immutable_fields}
 
-    def load_report_rows(self, connection=None, filters=None, **kwargs):
+    def load_report_rows(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReportRow]:
         """Loads reports rows into current instance
 
         >>> self.load_report_rows()
@@ -151,7 +160,9 @@ class DeepCrawlReport(ImmutableAttributesMixin):
         )
         return self.report_rows
 
-    def load_downloads(self, connection=None, filters=None, **kwargs):
+    def load_downloads(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReportDownload]:
         """Loads reports downloads into current instance
 
         >>> self.load_downloads()
@@ -181,14 +192,16 @@ class DeepCrawlReport(ImmutableAttributesMixin):
     REPORT ROWS
     """
 
-    def get_report_row(self, report_row_id, connection=None):
+    def get_report_row(
+            self, report_row_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlReportRow:
         """Get report row
 
         >>> self.get_report_row(1)
         <deepcrawl.reports.report_row.DeepCrawlReportRow at 0x108a20600>
 
         :param report_row_id: report row id
-        :type report_row_id: int
+        :type report_row_id: int or str
         :param connection: connection
         :type connection: deepcrawl.DeepCrawlConnection
         :return: report row instance
@@ -197,7 +210,10 @@ class DeepCrawlReport(ImmutableAttributesMixin):
         connection = connection or deepcrawl.DeepCrawlConnection.get_instance()
         return connection.get_report_row(self.account_id, self.project_id, self.crawl_id, self.id, report_row_id)
 
-    def get_report_rows(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_report_rows(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReportRow]:
         """Get report rows for current instance
 
         * use_cache=True > get_report_rows will return cached report rows or will do a call to DeepCrawl if report_rows attribute is empty.
@@ -223,7 +239,9 @@ class DeepCrawlReport(ImmutableAttributesMixin):
             return self.report_rows
         return self.load_report_rows(connection=connection, filters=filters, **kwargs)
 
-    def get_report_row_count(self, connection=None, filters=None):
+    def get_report_row_count(
+            self, connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None
+    ) -> str:
         """Get report row count
 
         >>> self.get_report_row_count()
@@ -244,7 +262,10 @@ class DeepCrawlReport(ImmutableAttributesMixin):
     """
     REPORT DOWNLOADS
     """
-    def create_report_download(self, download_data, connection=None):
+
+    def create_report_download(
+            self, download_data: dict, connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlReportDownload:
         """Create report download
 
         .. code-block::
@@ -270,7 +291,9 @@ class DeepCrawlReport(ImmutableAttributesMixin):
             self.account_id, self.project_id, self.crawl_id, self.id, download_data
         )
 
-    def get_report_download(self, report_download_id, connection=None):
+    def get_report_download(
+            self, report_download_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> DeepCrawlReportDownload:
         """Get report download
 
         >>> self.get_report_download(6)
@@ -288,7 +311,9 @@ class DeepCrawlReport(ImmutableAttributesMixin):
             self.account_id, self.project_id, self.crawl_id, self.id, report_download_id
         )
 
-    def delete_report_download(self, report_download_id, connection=None):
+    def delete_report_download(
+            self, report_download_id: Union[int, str], connection: 'deepcrawl.DeepCrawlConnection' = None
+    ) -> Response:
         """Delete report download
 
         >>> response = self.delete_report_download(report_download_id)
@@ -306,7 +331,10 @@ class DeepCrawlReport(ImmutableAttributesMixin):
             self.account_id, self.project_id, self.crawl_id, self.id, report_download_id
         )
 
-    def get_report_downloads(self, use_cache=True, connection=None, filters=None, **kwargs):
+    def get_report_downloads(
+            self, use_cache: bool = True,
+            connection: 'deepcrawl.DeepCrawlConnection' = None, filters: Optional[dict] = None, **kwargs
+    ) -> List[DeepCrawlReportDownload]:
         """Get report downloads
 
         >>> self.get_report_downloads()
