@@ -3,6 +3,8 @@ ReportRow
 =========
 """
 
+from typing import Union
+
 from deepcrawl.utils import ImmutableAttributesMixin
 
 report_row_extra_fields = (
@@ -32,8 +34,10 @@ class DeepCrawlReportRow(ImmutableAttributesMixin):
 
     mutable_attributes = report_row_mutable_fields
 
-    def __init__(self, account_id, project_id, crawl_id, report_id, row_data: dict):
-
+    def __init__(
+            self, account_id: Union[int, str], project_id: Union[int, str], crawl_id: Union[int, str],
+            report_id: str, row_data: dict
+    ):
         # relations
         self.id = row_data.get("_href", "").split("/")[-1]
         self.account_id = account_id
@@ -47,7 +51,7 @@ class DeepCrawlReportRow(ImmutableAttributesMixin):
         super(DeepCrawlReportRow, self).__init__()
 
     @property
-    def to_dict_mutable_fields(self):
+    def to_dict_mutable_fields(self) -> dict:
         """
         :return: dictionary with the mutable fields
         :rtype: dict
@@ -55,10 +59,9 @@ class DeepCrawlReportRow(ImmutableAttributesMixin):
         return {x: getattr(self, x, None) for x in report_row_mutable_fields}
 
     @property
-    def to_dict_immutable_fields(self):
+    def to_dict_immutable_fields(self) -> dict:
         """
         :return: dictionary with the immutable fields
         :rtype: dict
         """
         return {x: getattr(self, x, None) for x in report_row_immutable_fields}
-
