@@ -1,3 +1,6 @@
+from datetime import datetime
+from typing import Union
+
 from dateutil import parser
 
 from deepcrawl.exceptions import ImmutableAttributeError
@@ -18,11 +21,11 @@ class ImmutableAttributesMixin:
         super(ImmutableAttributesMixin, self).__setattr__(key, value)
 
     @property
-    def to_dict(self):
+    def to_dict(self) -> dict:
         return {x: getattr(self, x, None) for x in self.__slots__}
 
 
-def safe_string_to_datetime(str_):
+def safe_string_to_datetime(str_: str) -> Union[datetime, str]:
     try:
         return parser.parse(str_)
     except Exception:
